@@ -31,8 +31,8 @@ class ADAuthorizationAuthorizer extends MysqlAuthorizer
         }
 
         // Set up connection to LDAP server
-        $this->ldap_connection = @ldap_connect(Config::get('auth_ad_url'));
-        if (! $this->ldap_connection) {
+        $this->ldap_connection = ldap_connect(Config::get('auth_ad_url'));
+        if (empty($this->ldap_connection)) {
             throw new AuthenticationException('Fatal error while connecting to AD, uri not valid: ' . Config::get('auth_ad_url'));
         }
 
