@@ -334,10 +334,10 @@ class LdapAuthorizer extends AuthorizerBase
             $uri = $scheme . $uri . ':' . $port;
         }
 
-        $this->ldap_connection = @ldap_connect($uri);
+        $this->ldap_connection = ldap_connect($uri);
 
-        if (! $this->ldap_connection) {
-            throw new AuthenticationException('Unable to connect to ldap server');
+        if (empty($this->ldap_connection)) {
+            throw new AuthenticationException('Fatal error while connecting to LDAP server, uri not valid: ' . $uri);
         }
 
         ldap_set_option($this->ldap_connection, LDAP_OPT_PROTOCOL_VERSION, Config::get('auth_ldap_version', 3));
