@@ -33,6 +33,7 @@ use Illuminate\Support\Arr;
 use LibreNMS\Util\Oid;
 use LibreNMS\Util\StringHelpers;
 use Log;
+use SnmpQuery;
 
 trait YamlOSDiscovery
 {
@@ -59,7 +60,11 @@ trait YamlOSDiscovery
         }
 
         if (isset($os_yaml['hardware_mib'])) {
-            $this->translateSysObjectID($os_yaml['hardware_mib'], $os_yaml['hardware_regex'] ?? null);
+            $device->hardware = SnmpQuery::mibs([$os_yaml['hardware_mib']])->hideMib()->translate($device->sysObjectID);
+
+            if (! empty($os_yaml['hardware_regex'])) {
+                $this->parseRegex($os_yaml['hardware_regex'], $device->hardware);
+            }
         }
 
         $oids = Arr::only($os_yaml, $this->osFields);
@@ -113,7 +118,10 @@ trait YamlOSDiscovery
     {
         foreach (Arr::wrap($oids) as $oid) {
             // translate all to numeric to make it easier to match
-            $oid = ($numeric && ! Oid::of($oid)->isNumeric()) ? snmp_translate($oid, 'ALL', null, null, $this->getDeviceArray()) : $oid;
+            if ($numeric) {
+                $oid = Oid::of($oid)->toNumeric();
+            }
+
             if (! empty($data[$oid])) {
                 return $data[$oid];
             }
@@ -137,16 +145,6 @@ trait YamlOSDiscovery
         }
     }
 
-    private function translateSysObjectID($mib, $regex)
-    {
-        $device = $this->getDevice();
-        $device->hardware = snmp_translate($device->sysObjectID, $mib, null, '-Os', $this->getDeviceArray());
-
-        if ($regex) {
-            $this->parseRegex($regex, $device->hardware);
-        }
-    }
-
     private function fetch(array $oids, $numeric)
     {
         return snmp_get_multi_oid($this->getDeviceArray(), $oids, $numeric ? '-OUQn' : '-OUQ');
