@@ -91,13 +91,18 @@ class ModuleTestHelper
         Config::set('prometheus.enable', false);
     }
 
-    private static function compareOid($a, $b)
+    private static function compareOid($a, $b): int
     {
         $a_oid = explode('.', $a);
         $b_oid = explode('.', $b);
 
         foreach ($a_oid as $index => $a_part) {
+            if (! isset($b_oid[$index])) {
+                return 1; // a is higher (b doesn't exist)
+            }
+
             $b_part = $b_oid[$index];
+
             if ($a_part > $b_part) {
                 return 1; // a is higher
             } elseif ($a_part < $b_part) {
@@ -298,7 +303,7 @@ class ModuleTestHelper
 
         if (! Str::contains($full_name, '_')) {
             return [$full_name, ''];
-        } elseif (is_file(Config::get('install_dir') . "/includes/definitions/$full_name.yaml")) {
+        } elseif (is_file(resource_path("definitions/os_detection/$full_name.yaml"))) {
             return [$full_name, ''];
         } else {
             [$rvar, $ros] = explode('_', strrev($full_name), 2);
@@ -560,8 +565,8 @@ class ModuleTestHelper
             throw new FileNotFoundException("$this->snmprec_file does not exist!");
         }
 
-        // Remove existing device in case it didn't get removed previously
-        if (($existing_device = device_by_name($snmpSimIp)) && isset($existing_device['device_id'])) {
+        // Remove existing device in case it didn't get removed previously, if we're not running in CI
+        if (! getenv('CI') && ($existing_device = device_by_name($snmpSimIp)) && isset($existing_device['device_id'])) {
             delete_device($existing_device['device_id']);
         }
 
@@ -646,8 +651,9 @@ class ModuleTestHelper
         // Dump polled data
         $data = array_merge_recursive($data, $this->dumpDb($device_id, $polled_modules, 'poller'));
 
-        // Remove the test device, we don't need the debug from this
-        if ($device['hostname'] == $snmpSimIp) {
+        // Remove the test device, if we're not running in CI
+        if (! getenv('CI') && $device['hostname'] == $snmpSimIp) {
+            // we don't need the debug from this
             Debug::set(false);
             delete_device($device_id);
         }
