@@ -23,6 +23,7 @@
 
 namespace LibreNMS\Validations;
 
+use Exception;
 use Illuminate\Support\Facades\Cache;
 use LibreNMS\Config;
 use LibreNMS\ValidationResult;
@@ -38,7 +39,15 @@ class Scheduler extends BaseValidation
      */
     public function validate(Validator $validator): void
     {
-        if (! Cache::has('scheduler_working')) {
+        try {
+            $scheduler_working = Cache::has('scheduler_working');
+        } catch (Exception $e) {
+            $validator->fail(trans('validation.validations.poller.CheckLocking.fail', ['message' => $e->getMessage()]));
+
+            return;
+        }
+
+        if (! $scheduler_working) {
             $commands = $this->generateCommands($validator);
             $validator->result(ValidationResult::fail('Scheduler is not running')->setFix($commands));
         }
