@@ -1,4 +1,5 @@
 <?php
+
 /**
  * AddUserCommand.php
  *
@@ -27,11 +28,10 @@ namespace App\Console\Commands;
 
 use App\Console\LnmsCommand;
 use App\Models\User;
-use Bouncer;
-use Database\Seeders\RolesSeeder;
 use Illuminate\Validation\Rule;
 use LibreNMS\Authentication\LegacyAuth;
 use LibreNMS\Config;
+use Spatie\Permission\Models\Role;
 use Symfony\Component\Console\Input\InputArgument;
 use Symfony\Component\Console\Input\InputOption;
 
@@ -60,22 +60,15 @@ class AddUserCommand extends LnmsCommand
 
     /**
      * Execute the console command.
-     *
-     * @return mixed
      */
-    public function handle()
+    public function handle(): int
     {
         if (Config::get('auth_mechanism') != 'mysql') {
             $this->warn(__('commands.user:add.wrong-auth'));
         }
 
-        $roles = Bouncer::role()->pluck('name');
-
-        // missing roles, add them
-        if ($roles->isEmpty()) {
-            (new RolesSeeder)->run();
-            $roles = Bouncer::role()->pluck('name');
-        }
+        $roles = Role::query()->pluck('name')
+            ->whenEmpty(fn () => collect(['admin', 'global-read', 'user']));
 
         $this->validate([
             'username' => ['required', Rule::unique('users', 'username')->where('auth_type', 'mysql')],
@@ -99,7 +92,7 @@ class AddUserCommand extends LnmsCommand
 
         $user->setPassword($password);
         $user->save();
-        $user->assign($this->option('role'));
+        $user->assignRole($this->option('role'));
 
         $user->auth_id = (string) LegacyAuth::get()->getUserid($user->username) ?: $user->user_id;
         $user->save();
