@@ -1,4 +1,5 @@
 <?php
+
 /**
  * SmokepingGenerateCommand.php
  *
@@ -71,7 +72,7 @@ class SmokepingGenerateCommand extends LnmsCommand
      *
      * @return int
      */
-    public function handle()
+    public function handle(): int
     {
         if (! $this->validateOptions()) {
             return 1;
