@@ -33,6 +33,8 @@ use LibreNMS\Config;
 
 class OutagesController extends TableController
 {
+    protected $model = DeviceOutage::class;
+
     public function rules()
     {
         return [
@@ -132,4 +134,35 @@ class OutagesController extends TableController
 
         return $output;
     }
+
+    /**
+     * Get headers for CSV export
+     *
+     * @return array
+     */
+    protected function getExportHeaders()
+    {
+        return [
+            'Device Hostname',
+            'Start',
+            'End',
+            'Duration',
+        ];
+    }
+
+    /**
+     * Format a row for CSV export
+     *
+     * @param  DeviceOutage  $outage
+     * @return array
+     */
+    protected function formatExportRow($outage)
+    {
+        return [
+            $outage->device ? $outage->device->displayName() : '',
+            $this->formatDatetime($outage->going_down),
+            $outage->up_again ? $this->formatDatetime($outage->up_again) : '-',
+            $this->formatTime(($outage->up_again ?: time()) - $outage->going_down),
+        ];
+    }
 }
