@@ -43,11 +43,22 @@ class Location extends Model
     public $fillable = ['location', 'lat', 'lng'];
     const CREATED_AT = null;
     const UPDATED_AT = 'timestamp';
-    protected $casts = ['lat' => 'float', 'lng' => 'float', 'fixed_coordinates' => 'bool'];
 
     private $location_regex = '/\[\s*(?<lat>[-+]?(?:[1-8]?\d(?:\.\d+)?|90(?:\.0+)?))\s*,\s*(?<lng>[-+]?(?:180(?:\.0+)?|(?:(?:1[0-7]\d)|(?:[1-9]?\d))(?:\.\d+)?))\s*\]/';
     private $location_ignore_regex = '/\(.*?\)/';
 
+    /**
+     * @return array{lat: 'float', lng: 'float', fixed_coordinates: 'bool'}
+     */
+    protected function casts(): array
+    {
+        return [
+            'lat' => 'float',
+            'lng' => 'float',
+            'fixed_coordinates' => 'bool',
+        ];
+    }
+
     // ---- Helper Functions ----
 
     /**
@@ -170,7 +181,9 @@ class Location extends Model
     }
 
     // ---- Define Relationships ----
-
+    /**
+     * @return \Illuminate\Database\Eloquent\Relations\HasMany<\App\Models\Device, $this>
+     */
     public function devices(): HasMany
     {
         return $this->hasMany(Device::class, 'location_id');
