@@ -4,14 +4,14 @@ use Illuminate\Database\Migrations\Migration;
 use Illuminate\Database\Schema\Blueprint;
 use Illuminate\Support\Facades\Schema;
 
-class UpdatePortsStpUniqueIndex extends Migration
+return new class extends Migration
 {
     /**
      * Run the migrations.
      *
      * @return void
      */
-    public function up()
+    public function up(): void
     {
         Schema::table('ports_stp', function (Blueprint $table) {
             $table->unique(['device_id', 'vlan', 'port_index']);
@@ -23,10 +23,10 @@ class UpdatePortsStpUniqueIndex extends Migration
      *
      * @return void
      */
-    public function down()
+    public function down(): void
     {
         Schema::table('ports_stp', function (Blueprint $table) {
             $table->dropIndex('ports_stp_device_id_vlan_port_index_unique');
         });
     }
-}
+};
