@@ -15,8 +15,6 @@
 use App\Actions\Device\ValidateDeviceAndCreate;
 use App\Models\Device;
 use App\Models\Eventlog;
-use App\Models\Ipv4Address;
-use App\Models\Ipv4Network;
 use Illuminate\Support\Facades\Log;
 use Illuminate\Support\Str;
 use LibreNMS\Config;
@@ -42,6 +40,11 @@ use LibreNMS\Util\UserFuncHelper;
 function discover_new_device($hostname, $device, $method, $interface = null)
 {
     Log::debug("discovering $hostname\n");
+    if (empty(Config::get('nets'))) {
+        Log::debug("Allowed discovery network list is empty - skipping\n");
+
+        return false;
+    }
 
     if (IP::isValid($hostname)) {
         $ip = $hostname;
@@ -167,15 +170,14 @@ function discover_device(&$device, $force_module = false)
             try {
                 include "includes/discovery/$module.inc.php";
             } catch (Throwable $e) {
-                // isolate module exceptions so they don't disrupt the polling process
-                Log::error("%rError discovering $module module for {$device['hostname']}.%n $e", ['color' => true]);
-                Eventlog::log("Error discovering $module module. Check log file for more details.", $device['device_id'], 'discovery', Severity::Error);
-                report($e);
-
-                // Re-throw exception if we're in CI
-                if (getenv('CI') == true) {
+                // Re-throw exception if we're in running tests
+                if (defined('PHPUNIT_RUNNING')) {
                     throw $e;
                 }
+
+                // isolate module exceptions so they don't disrupt the polling process
+                Eventlog::log("Error discovering $module module. Check log file for more details.", $device['device_id'], 'discovery', Severity::Error);
+                report($e);
             }
 
             $module_time = microtime(true) - $module_start;
@@ -314,75 +316,6 @@ function discover_link($local_port_id, $protocol, $remote_port_id, $remote_hostn
     $link_exists[$local_port_id][$remote_hostname][$remote_port] = 1;
 }
 
-/**
- * create or update IPv4 Addresses and/or IPv4 Networks
- *
- * @param  pointer  $valid_v4
- * @param  array  $device
- * @param  int  $ifIndex
- * @param  string  $ipv4_address
- * @param  string  $mask
- * @param  string  $context_name
- * @return array
- *
- * @throws InvalidIpException
- */
-function discover_process_ipv4(&$valid_v4, $device, int $ifIndex, $ipv4_address, $mask, $context_name = '')
-{
-    $cidr = IPv4::netmask2cidr($mask);
-    try {
-        $ipv4 = new IPv4($ipv4_address . '/' . $cidr);
-    } catch (InvalidIpException $e) {
-        Log::debug('Invalid data: ' . $ipv4_address);
-
-        return;
-    }
-    $ipv4_network = $ipv4->getNetworkAddress() . '/' . $ipv4->cidr;
-
-    if ($ipv4_address != '0.0.0.0' && $ifIndex > 0) {
-        $port_id = \App\Facades\PortCache::getIdFromIfIndex($ifIndex, $device['device_id']);
-
-        if (is_numeric($port_id)) {
-            $dbIpv4Net = Ipv4Network::updateOrCreate([
-                'ipv4_network' => $ipv4_network,
-            ], [
-                'context_name' => $device['context_name'],
-            ]);
-
-            if (! $dbIpv4Net->wasRecentlyCreated && $dbIpv4Net->wasChanged()) {
-                Eventlog::log('IPv4 network ' . $ipv4_network . ' changed', $device['device_id'], 'ipv4', Severity::Warning);
-                echo 'Nu';
-            }
-            if ($dbIpv4Net->wasRecentlyCreated) {
-                Eventlog::log('IPv4 network ' . $ipv4_network . ' created', $device['device_id'], 'ipv4', Severity::Notice);
-                echo 'N+';
-            }
-
-            $ipv4_network_id = Ipv4Network::where('ipv4_network', $ipv4_network)->value('ipv4_network_id');
-            $dbIpv4Addr = Ipv4Address::updateOrCreate([
-                'ipv4_address' => $ipv4_address,
-                'ipv4_prefixlen' => $cidr,
-                'ipv4_network_id' => $ipv4_network_id,
-                'port_id' => $port_id,
-            ], [
-                'context_name' => $device['context_name'],
-            ]);
-
-            if (! $dbIpv4Addr->wasRecentlyCreated && $dbIpv4Addr->wasChanged()) {
-                Eventlog::log('IPv4 address ' . $ipv4_address . '/' . $cidr . ' changed', $device['device_id'], 'ipv4', Severity::Warning);
-                echo 'Au';
-            }
-            if ($dbIpv4Addr->wasRecentlyCreated) {
-                Eventlog::log('IPv4 address ' . $ipv4_address . '/' . $cidr . ' created', $device['device_id'], 'ipv4', Severity::Notice);
-                echo 'A+';
-            }
-            $full_address = $ipv4_address . '/' . $cidr . '|' . $ifIndex;
-            $valid_v4[$full_address] = 1;
-        } else {
-            Log::debug('No port id found for ifindex: ' . $ifIndex . PHP_EOL);
-        }
-    }
-}
 /*
  * Check entity sensors to be excluded
  *
@@ -826,7 +759,7 @@ function add_cbgp_peer($device, $peer, $afi, $safi)
             'bgpPeerIdentifier' => $peer['ip'],
             'afi' => $afi,
             'safi' => $safi,
-            'context_name' => $device['context_name'],
+            'context_name' => $device['context_name'] ?? null,
             'AcceptedPrefixes' => 0,
             'DeniedPrefixes' => 0,
             'PrefixAdminLimit' => 0,
