@@ -27,6 +27,11 @@ if ($device['os'] == 'nokia-isam') {
     require base_path('includes/discovery/ports/nokia-isam.inc.php');
 }
 
+//Get Bison ports
+if ($device['os'] == 'bison') {
+    require base_path('includes/discovery/ports/bison.inc.php');
+}
+
 // Get adva-fsp150cp
 if ($device['os'] == 'adva-fsp150cp') {
     require base_path('includes/discovery/ports/adva-fsp150cp.inc.php');
