@@ -18,8 +18,10 @@ require 'includes/html/graphs/common.inc.php';
 
 $stacked = generate_stacked_graphs();
 
-$descr_len = $descr_len ?? 12;
-$unitlen = $unitlen ?? 0;
+$descr_len ??= 12;
+$unitlen ??= 0;
+$units ??= '';
+$unit_text ??= '';
 $rrd_optionsb = '';
 
 if ($nototal) {
@@ -32,7 +34,7 @@ $rrd_options .= " COMMENT:'" . \LibreNMS\Data\Store\Rrd::fixedSafeDescr($unit_te
 $i = 0;
 $iter = 0;
 
-foreach ($rrd_list as $rrd) {
+foreach ($rrd_list ?? [] as $rrd) {
     // get the color for this data set
     if (isset($rrd['colour'])) {
         $colour = $rrd['colour'];
