@@ -17,6 +17,10 @@
 require 'includes/html/graphs/common.inc.php';
 
 $stacked = generate_stacked_graphs();
+$filename ??= $rrd_filename; // use $rrd_filename
+$units ??= '';
+$unit_text ??= '';
+$rrd_optionsb = '';
 
 if (! isset($munge)) {
     $munge = false;
