@@ -10,6 +10,7 @@ $graph_array_zoom = $graph_array;
 $graph_array_zoom['height'] = '150';
 $graph_array_zoom['width'] = '400';
 $graph_array['legend'] = 'no';
+$width_div ??= 0;
 
 $index = 0;
 foreach (Application::query()->hasAccess(Auth::user())->with('device')->get()->sortBy('show_name', SORT_NATURAL | SORT_FLAG_CASE)->groupBy('app_type') as $type => $groupedApps) {
@@ -23,7 +24,7 @@ foreach (Application::query()->hasAccess(Auth::user())->with('device')->get()->s
     });
     /** @var Application $app */
     foreach ($groupedApps as $app) {
-        $graph_type = $graphs[$app->app_type][0];
+        $graph_type = $graphs[$app->app_type][0] ?? '';
 
         $graph_array['type'] = 'application_' . $app->app_type . '_' . $graph_type;
         $graph_array['id'] = $app->app_id;
@@ -35,6 +36,7 @@ foreach (Application::query()->hasAccess(Auth::user())->with('device')->get()->s
         $app_state = \LibreNMS\Util\Html::appStateIcon($app->app_state);
         $app_state_info = '<font color="' . $app_state['color'] . '"><i title="' . $app_state['hover_text'] . '" class="fa ' . $app_state['icon'] . ' fa-fw fa-lg" aria-hidden="true"></i></font>';
 
+        $content_add = '';
         $overlib_link = '<span style="float:left; margin-left: 10px; font-weight: bold;">' . $app_state_info . htmlentities($app->device?->shortDisplayName() ?? '') . '</span>';
         if (! empty($app->app_instance)) {
             $overlib_link .= '<span style="float:right; margin-right: 10px; font-weight: bold;">' . $app->app_instance . '</span>';
