@@ -2,7 +2,16 @@
 
 $pagetitle[] = 'Routing';
 
-if ($_GET['optb'] == 'graphs' || $_GET['optc'] == 'graphs') {
+$optb = isset($_GET['optb']) ? $_GET['optb'] : '';
+$optc = isset($_GET['optc']) ? $_GET['optc'] : '';
+$vars['view'] = isset($vars['view']) ? $vars['view'] : 'basic';
+$vars['graph'] = isset($vars['graph']) ? $vars['graph'] : '';
+$vars['type'] = isset($vars['type']) ? $vars['type'] : 'all';
+$vars['adminstatus'] = isset($vars['adminstatus']) ? $vars['adminstatus'] : '';
+$vars['state'] = isset($vars['state']) ? $vars['state'] : '';
+$width = isset($vars['width']) ? $vars['width'] : '218';
+
+if ($optb == 'graphs' || $optc == 'graphs') {
     $graphs = 'graphs';
 } else {
     $graphs = 'nographs';
