@@ -22,7 +22,7 @@ print_optionbar_start('', '');
 
 echo '<span style="font-weight: bold;">Search</span> &#187; ';
 
-unset($sep);
+$sep = '';
 foreach ($sections as $type => $texttype) {
     echo $sep;
     if ($vars['search'] == $type) {
@@ -39,8 +39,6 @@ foreach ($sections as $type => $texttype) {
     $sep = ' | ';
 }
 
-unset($sep);
-
 print_optionbar_end();
 
 if (file_exists("includes/html/pages/search/$search_type.inc.php")) {
