@@ -44,6 +44,6 @@ $tags = [
     'rrd_def' => $rrd_def,
 ];
 
-data_update($device, 'app', $tags, $fields);
+app('Datastore')->put($device, 'app', $tags, $fields);
 
 update_application($app, $rawdata, $fields);
