@@ -91,7 +91,7 @@ foreach ($stat_vars as $key => $stat) {
     $fields = ['data' => $value];
     $metrics[$var_name] = $value;
     $tags = ['name' => $name, 'app_id' => $app->app_id, 'rrd_def' => $gauge_rrd_def, 'rrd_name' => $rrd_name];
-    data_update($device, 'app', $tags, $fields);
+    app('Datastore')->put($device, 'app', $tags, $fields);
 }
 
 // process each jail/ports/sets item
@@ -105,7 +105,7 @@ foreach ($data['jailANDportsANDset'] as $jps_key => $jps) {
         $fields = ['data' => $value];
         $metrics[$var_name] = $value;
         $tags = ['name' => $name, 'app_id' => $app->app_id, 'rrd_def' => $gauge_rrd_def, 'rrd_name' => $rrd_name];
-        data_update($device, 'app', $tags, $fields);
+        app('Datastore')->put($device, 'app', $tags, $fields);
     }
 }
 
