@@ -1,4 +1,5 @@
 <?php
+
 /**
  * powerdns-recursor.inc.php
  *
@@ -137,7 +138,7 @@ if (! empty($data)) {
         'rrd_name' => ['app', 'powerdns', 'recursor', $app->app_id],
         'rrd_def' => $rrd_def,
     ];
-    data_update($device, 'app', $tags, $fields);
+    app('Datastore')->put($device, 'app', $tags, $fields);
     update_application($app, $data, $fields);
 }
 
