@@ -45,7 +45,7 @@ $rrd_name = ['app', $name, $app->app_id, $category];
 
 $metrics[$category] = $fields;
 $tags = ['name' => $name, 'app_id' => $app->app_id, 'rrd_def' => $rrd_def, 'rrd_name' => $rrd_name];
-data_update($device, 'app', $tags, $fields);
+app('Datastore')->put($device, 'app', $tags, $fields);
 
 $category = 'memory';
 $fields = [
@@ -65,7 +65,7 @@ $rrd_name = ['app', $name, $app->app_id, $category];
 
 $metrics[$category] = $fields;
 $tags = ['name' => $name, 'app_id' => $app->app_id, 'rrd_def' => $rrd_def, 'rrd_name' => $rrd_name];
-data_update($device, 'app', $tags, $fields);
+app('Datastore')->put($device, 'app', $tags, $fields);
 
 $category = 'objects';
 $fields = [
@@ -77,7 +77,7 @@ $rrd_name = ['app', $name, $app->app_id, $category];
 
 $metrics[$category] = $fields;
 $tags = ['name' => $name, 'app_id' => $app->app_id, 'rrd_def' => $rrd_def, 'rrd_name' => $rrd_name];
-data_update($device, 'app', $tags, $fields);
+app('Datastore')->put($device, 'app', $tags, $fields);
 
 $category = 'fragmentation';
 $fields = [
@@ -89,7 +89,7 @@ $rrd_name = ['app', $name, $app->app_id, $category];
 
 $metrics[$category] = $fields;
 $tags = ['name' => $name, 'app_id' => $app->app_id, 'rrd_def' => $rrd_def, 'rrd_name' => $rrd_name];
-data_update($device, 'app', $tags, $fields);
+app('Datastore')->put($device, 'app', $tags, $fields);
 
 $category = 'usage';
 $fields = [
@@ -115,7 +115,7 @@ $rrd_name = ['app', $name, $app->app_id, $category];
 
 $metrics[$category] = $fields;
 $tags = ['name' => $name, 'app_id' => $app->app_id, 'rrd_def' => $rrd_def, 'rrd_name' => $rrd_name];
-data_update($device, 'app', $tags, $fields);
+app('Datastore')->put($device, 'app', $tags, $fields);
 
 $category = 'defrag';
 $fields = [
@@ -133,7 +133,7 @@ $rrd_name = ['app', $name, $app->app_id, $category];
 
 $metrics[$category] = $fields;
 $tags = ['name' => $name, 'app_id' => $app->app_id, 'rrd_def' => $rrd_def, 'rrd_name' => $rrd_name];
-data_update($device, 'app', $tags, $fields);
+app('Datastore')->put($device, 'app', $tags, $fields);
 
 $category = 'keyspace';
 $fields = [
@@ -147,7 +147,7 @@ $rrd_name = ['app', $name, $app->app_id, $category];
 
 $metrics[$category] = $fields;
 $tags = ['name' => $name, 'app_id' => $app->app_id, 'rrd_def' => $rrd_def, 'rrd_name' => $rrd_name];
-data_update($device, 'app', $tags, $fields);
+app('Datastore')->put($device, 'app', $tags, $fields);
 
 $category = 'sync';
 $fields = [
@@ -163,7 +163,7 @@ $rrd_name = ['app', $name, $app->app_id, $category];
 
 $metrics[$category] = $fields;
 $tags = ['name' => $name, 'app_id' => $app->app_id, 'rrd_def' => $rrd_def, 'rrd_name' => $rrd_name];
-data_update($device, 'app', $tags, $fields);
+app('Datastore')->put($device, 'app', $tags, $fields);
 
 $category = 'commands';
 $fields = [
@@ -175,7 +175,7 @@ $rrd_name = ['app', $name, $app->app_id, $category];
 
 $metrics[$category] = $fields;
 $tags = ['name' => $name, 'app_id' => $app->app_id, 'rrd_def' => $rrd_def, 'rrd_name' => $rrd_name];
-data_update($device, 'app', $tags, $fields);
+app('Datastore')->put($device, 'app', $tags, $fields);
 
 $category = 'connections';
 $fields = [
@@ -189,7 +189,7 @@ $rrd_name = ['app', $name, $app->app_id, $category];
 
 $metrics[$category] = $fields;
 $tags = ['name' => $name, 'app_id' => $app->app_id, 'rrd_def' => $rrd_def, 'rrd_name' => $rrd_name];
-data_update($device, 'app', $tags, $fields);
+app('Datastore')->put($device, 'app', $tags, $fields);
 
 $category = 'net';
 $fields = [
@@ -203,6 +203,6 @@ $rrd_name = ['app', $name, $app->app_id, $category];
 
 $metrics[$category] = $fields;
 $tags = ['name' => $name, 'app_id' => $app->app_id, 'rrd_def' => $rrd_def, 'rrd_name' => $rrd_name];
-data_update($device, 'app', $tags, $fields);
+app('Datastore')->put($device, 'app', $tags, $fields);
 
 update_application($app, $output, $metrics);
