@@ -1,4 +1,5 @@
 <?php
+
 /**
  * rrdcached.inc.php
  *
@@ -99,7 +100,7 @@ $tags = [
     'rrd_name' => ['app', $name, $app->app_id],
     'rrd_def' => $rrd_def,
 ];
-data_update($device, 'app', $tags, $fields);
+app('Datastore')->put($device, 'app', $tags, $fields);
 update_application($app, $data, $fields);
 
 unset($data, $rrd_def, $fields, $tags);
