@@ -59,7 +59,7 @@ if ($device['os_group'] == 'cisco') {
 
         if (isset($serverfarms[$farm_id])) {
             $tags = compact('farm_id', 'rrd_name', 'rrd_def');
-            data_update($device, 'rservers', $tags, $fields);
+            app('Datastore')->put($device, 'rservers', $tags, $fields);
         }
     }//end foreach
 
