@@ -3,6 +3,7 @@
 use App\Models\Eventlog;
 use Illuminate\Support\Str;
 use LibreNMS\Config;
+use LibreNMS\Enum\Sensor;
 use LibreNMS\Enum\Severity;
 use LibreNMS\Exceptions\JsonAppBase64DecodeException;
 use LibreNMS\Exceptions\JsonAppBlankJsonException;
@@ -134,42 +135,9 @@ function poll_sensor($device, $class)
  */
 function record_sensor_data($device, $all_sensors)
 {
-    $supported_sensors = [
-        'airflow' => 'cfm',
-        'ber' => '',
-        'bitrate' => 'bps',
-        'charge' => '%',
-        'chromatic_dispersion' => 'ps/nm',
-        'cooling' => 'W',
-        'count' => '',
-        'current' => 'A',
-        'delay' => 's',
-        'dbm' => 'dBm',
-        'eer' => 'eer',
-        'fanspeed' => 'rpm',
-        'frequency' => 'Hz',
-        'humidity' => '%',
-        'load' => '%',
-        'loss' => '%',
-        'percent' => '%',
-        'power' => 'W',
-        'power_consumed' => 'kWh',
-        'power_factor' => '',
-        'pressure' => 'kPa',
-        'quality_factor' => 'dB',
-        'runtime' => 'Min',
-        'signal' => 'dBm',
-        'snr' => 'SNR',
-        'state' => '#',
-        'temperature' => 'C',
-        'tv_signal' => 'dBmV',
-        'voltage' => 'V',
-        'waterflow' => 'l/m',
-    ];
-
     foreach ($all_sensors as $sensor) {
-        $class = ucfirst($sensor['sensor_class']);
-        $unit = $supported_sensors[$sensor['sensor_class']];
+        $class = trans('sensors.' . $sensor['sensor_class'] . '.short');
+        $unit = Sensor::from($sensor['sensor_class'])->unit();
         $sensor_value = Number::extract($sensor['new_value']);
         $prev_sensor_value = $sensor['sensor_current'];
 
@@ -232,7 +200,7 @@ function record_sensor_data($device, $all_sensors)
                 'state_value'
             );
 
-            Eventlog::log("$class sensor {$sensor['sensor_descr']} has changed from {$trans[$prev_sensor_value]} ($prev_sensor_value) to {$trans[$sensor_value]} ($sensor_value)", $device['device_id'], $class, Severity::Notice, $sensor['sensor_id']);
+            Eventlog::log('$class sensor ' . ($sensor['sensor_descr'] ?? '') . ' has changed from ' . ($trans[$prev_sensor_value] ?? '#unamed state#') . "($prev_sensor_value) to " . ($trans[$sensor_value] ?? '#unamed state#') . " ($sensor_value)", $device['device_id'], $class, Severity::Notice, $sensor['sensor_id']);
         }
         if ($sensor_value != $prev_sensor_value) {
             dbUpdate(['sensor_current' => $sensor_value, 'sensor_prev' => $prev_sensor_value, 'lastupdate' => ['NOW()']], 'sensors', '`sensor_class` = ? AND `sensor_id` = ?', [$sensor['sensor_class'], $sensor['sensor_id']]);
