@@ -34,7 +34,7 @@ if ($this_port['dot3StatsIndex'] and $port['ifType'] == 'ethernetCsmacd') {
     }
 
     $tags = compact('ifName', 'rrd_name', 'rrd_def', 'rrd_oldname');
-    data_update($device, 'dot3', $tags, $fields);
+    app('Datastore')->put($device, 'dot3', $tags, $fields);
 
     echo 'EtherLike ';
 }
