@@ -41,9 +41,12 @@ return [
             'general' => ['name' => 'General Discovery Settings'],
             'route' => ['name' => 'Routes Discovery Module'],
             'discovery_modules' => ['name' => 'Discovery Modules'],
+            'autodiscovery' => ['name' => 'Network Discovery'],
             'ports' => ['name' => 'Ports Module'],
             'storage' => ['name' => 'Storage Module'],
-            'networks' => ['name' => 'Networks'],
+            'ipmi' => ['name' => 'IPMI Module'],
+            'sensors' => ['name' => 'Sensors Module'],
+            'virtualization' => ['name' => 'Virtualization Module'],
         ],
         'external' => [
             'binaries' => ['name' => 'Binary Locations'],
@@ -56,6 +59,8 @@ return [
             'unix-agent' => ['name' => 'Unix-Agent Integration'],
             'smokeping' => ['name' => 'Smokeping Integration'],
             'snmptrapd' => ['name' => 'SNMP Traps Integration'],
+            'rancid' => ['name' => 'RANCID Integration'],
+            'collectd' => ['name' => 'Collectd Integration'],
         ],
         'poller' => [
             'availability' => ['name' => 'Device Availability'],
@@ -70,8 +75,10 @@ return [
             'snmp' => ['name' => 'SNMP'],
             'dispatcherservice' => ['name' => 'Dispatcher Service'],
             'poller_modules' => ['name' => 'Poller Modules'],
+            'ports' => ['name' => 'Ports Poller Module'],
         ],
         'system' => [
+            'billing' => ['name' => 'Billing'],
             'cleanup' => ['name' => 'Cleanup'],
             'proxy' => ['name' => 'Proxy'],
             'updates' => ['name' => 'Updates'],
@@ -89,6 +96,9 @@ return [
             'style' => ['name' => 'Style'],
             'device' => ['name' => 'Device Settings'],
             'worldmap' => ['name' => 'World Map Settings'],
+            'general' => ['name' => 'General Web UI Settings'],
+            'front-page' => ['name' => 'Front Page Settings'],
+            'menu' => ['name' => 'Menu Settings'],
         ],
     ],
     'settings' => [
@@ -295,6 +305,13 @@ return [
                     'description' => 'Scopes that should be included with in the authentication request',
                     'help' => 'See https://laravel.com/docs/10.x/socialite#access-scopes',
                 ],
+                'default_role' => [
+                    'description' => 'Default Role',
+                ],
+                'claims' => [
+                    'description' => 'Claims',
+                    'help' => 'Map groups to Roles',
+                ],
             ],
         ],
         'auth_ad_base_dn' => [
@@ -493,6 +510,20 @@ return [
             'description' => 'Auth log entries older than',
             'help' => 'Cleanup done by daily.sh',
         ],
+        'bad_entity_sensor_regex' => [
+            'description' => 'Bad Entity Sensor Regex',
+            'help' => 'Regex to match bad entity sensors, these will not be displayed in the web interface.',
+        ],
+        'billing' => [
+            '95th_default_agg' => [
+                'description' => 'Default 95th Percentile Aggregation',
+                'help' => 'Set default option for 95th percentile calculation as aggregate.',
+            ],
+        ],
+        'enable_billing' => [
+            'description' => 'Enable Billing',
+            'help' => 'Enable billing module, this allows you to monitor port usage.',
+        ],
         'peering_descr' => [
             'description' => 'Peering Port Types',
             'help' => 'Ports of the listed description type(s) will be shown under the peering ports menu entry.  See Interface Description Parsing docs for more info.',
@@ -501,10 +532,22 @@ return [
             'description' => 'Transit Port Types',
             'help' => 'Ports of the listed description type(s) will be shown under the transit ports menu entry.  See Interface Description Parsing docs for more info.',
         ],
+        'collectd_dir' => [
+            'description' => 'Collectd Directory',
+            'help' => 'Directory where collectd stores its RRD files.  This is used to display data from collectd into LibreNMS.',
+        ],
+        'collectd_sock' => [
+            'description' => 'Collectd Socket',
+            'help' => 'Socket collectd is listening on.  This is used to display data from collectd into LibreNMS.',
+        ],
         'core_descr' => [
             'description' => 'Core Port Types',
             'help' => 'Ports of the listed description type(s) will be shown under the core ports menu entry.  See Interface Description Parsing docs for more info.',
         ],
+        'custom_descr' => [
+            'description' => 'Custom Port Types',
+            'help' => 'Ports of the listed description type(s) will be shown under the custom ports menu entry.  See Interface Description Parsing docs for more info.',
+        ],
         'custom_map' => [
             'background_type' => [
                 'description' => 'Background Type',
@@ -598,9 +641,17 @@ return [
             'help' => 'Ports of the listed description type(s) will be shown under the customers ports menu entry.  See Interface Description Parsing docs for more info.',
         ],
         'base_url' => [
-            'description' => 'Specific URL',
+            'description' => 'Base URL',
             'help' => 'This should *only* be set if you want to *force* a particular hostname/port. It will prevent the web interface being usable form any other hostname',
         ],
+        'disabled_sensors' => [
+            'description' => 'Disabled Sensors',
+            'help' => 'Sensors that should not be polled or displayed in the web interface.',
+        ],
+        'disabled_sensors_regex' => [
+            'description' => 'Disabled Sensors Regex',
+            'help' => 'Sensors that match this regex will not be polled or displayed in the web interface.',
+        ],
         'discovery_modules' => [
             'arp-table' => [
                 'description' => 'ARP Table',
@@ -742,6 +793,10 @@ return [
             'description' => 'Default Poller Group',
             'help' => 'The default poller group all pollers should poll if none is set in config.php',
         ],
+        'device_traffic_iftype' => [
+            'description' => 'Device Traffic Interface Types',
+            'help' => 'Interface types to be excluded from device graphs.',
+        ],
         'distributed_poller_memcached_host' => [
             'description' => 'Memcached host',
             'help' => 'The hostname or ip for the memcached server. This is required for poller_wrapper.py and daily.sh locking.',
@@ -754,6 +809,14 @@ return [
             'description' => 'Auto TLS support',
             'help' => 'Tries to use TLS before falling back to un-encrypted',
         ],
+        'email_smtp_verifypeer' => [
+            'description' => 'Verify peer certificate',
+            'help' => 'Do not verify peer certificate when connecting to SMTP server via TLS',
+        ],
+        'email_smtp_allowselfsigned' => [
+            'description' => 'Allow self-signed certificate',
+            'help' => 'Allow self-signed certificate when connecting to SMTP server via TLS',
+        ],
         'email_attach_graphs' => [
             'description' => 'Attach graph images',
             'help' => 'This will generate a graph when the alert is raised and attach it and embed it in the email.',
@@ -810,6 +873,38 @@ return [
             'description' => 'From name',
             'help' => 'Name used as part of the from address',
         ],
+        'enable_clear_discovery' => [
+            'description' => 'Enable Clear Discovery',
+            'help' => 'Enables the ability to clear discovery date and time for a device. This will force a rediscovery of the device.',
+        ],
+        'enable_footer' => [
+            'description' => 'Enable Footer',
+            'help' => 'Enables the footer on all pages.',
+        ],
+        'enable_inventory' => [
+            'description' => 'Enable Inventory',
+            'help' => 'Enables the inventory page, which shows the hardware inventory of devices.',
+        ],
+        'enable_lazy_load' => [
+            'description' => 'Enable Lazy Loading',
+            'help' => 'Lazy loading is used to speed up the loading of pages by only loading the data that is needed at the time. This can be disabled if you have issues with it.',
+        ],
+        'enable_libvirt' => [
+            'description' => 'Enable Libvirt',
+            'help' => 'Enables the libvirt page, which shows the virtual machines of devices.',
+        ],
+        'enable_proxmox' => [
+            'description' => 'Enable Proxmox',
+            'help' => 'Enables the Proxmox page, which shows the virtual machines of devices.',
+        ],
+        'enable_pseudowires' => [
+            'description' => 'Enable Pseudowires',
+            'help' => 'Enables the pseudowires page, which shows the pseudowires of devices.',
+        ],
+        'enable_syslog' => [
+            'description' => 'Enable Syslog',
+            'help' => 'Enables visibility for syslog within the WebUI.',
+        ],
         'eventlog_purge' => [
             'description' => 'Event log entries older than',
             'help' => 'Cleanup done by daily.sh',
@@ -818,6 +913,24 @@ return [
             'description' => 'Favicon',
             'help' => 'Overrides the default favicon.',
         ],
+        'front_page' => [
+            'description' => 'Front Page',
+            'help' => 'Set a custom front page, this is the page you see when you first log in. For example, if you create `resources/views/overview/custom/foobar.blade.php`, set `front_page` to `foobar`',
+        ],
+        'front_page_down_box_limit' => [
+            'description' => 'Down Devices Limit',
+            'help' => 'Number of devices to show in the down box on the front page',
+        ],
+        'front_page_settings' => [
+            'top_devices' => [
+                'description' => 'Top Devices',
+                'help' => 'Number of top devices to show on the front page',
+            ],
+            'top_ports' => [
+                'description' => 'Top Ports',
+                'help' => 'Number of top ports to show on the front page',
+            ],
+        ],
         'fping' => [
             'description' => 'Path to fping',
         ],
@@ -975,6 +1088,10 @@ return [
             'description' => 'HTTPS Proxy',
             'help' => 'Set this as a fallback if https_proxy environment variable is not available.',
         ],
+        'icmp_check' => [
+            'description' => 'ICMP Check',
+            'help' => 'Enable ICMP check for all devices globally, this will ping devices to check if they are up or down. Disabling this could lead to polling not completing in time.',
+        ],
         'ignore_mount' => [
             'description' => 'Mountpoints to be ignored',
             'help' => 'Don\'t monitor Disc Usage of this Mountpoints',
@@ -1108,9 +1225,57 @@ return [
                 'help' => 'How many reties we should try',
             ],
         ],
+        'int_core' => [
+            'description' => 'Enable Core Ports menu',
+            'help' => 'Enable core ports menu in the web interface',
+        ],
+        'int_customers' => [
+            'description' => 'Enable Customers Ports menu',
+            'help' => 'Enable customers ports menu in the web interface',
+        ],
+        'int_peering' => [
+            'description' => 'Enable Peering Ports menu',
+            'help' => 'Enable peering ports menu in the web interface',
+        ],
+        'int_transit' => [
+            'description' => 'Enable Transit Ports menu',
+            'help' => 'Enable transit ports menu in the web interface',
+        ],
+        'int_l2tp' => [
+            'description' => 'Enable L2TP Ports menu',
+            'help' => 'Enable L2TP ports menu in the web interface',
+        ],
         'ipmitool' => [
             'description' => 'Path to ipmtool',
         ],
+        'ipmi.type' => [
+            'description' => 'IPMI Type',
+            'help' => 'Type of IPMI to use, can be `lan`, `lanplus`, `open`, `sol`, `raw` or `shell`',
+        ],
+        'ipmi_unit' => [
+            'description' => 'IPMI Unit',
+            'help' => 'IPMI unit types that can be discovered.',
+        ],
+        'libvirt_protocols' => [
+            'description' => 'Libvirt Protocols',
+            'help' => 'Protocols to use for libvirt connections.',
+        ],
+        'libvirt_username' => [
+            'description' => 'Libvirt Username',
+            'help' => 'Username to use for libvirt connections.',
+        ],
+        'location_map' => [
+            'description' => 'Specific Location Map',
+            'help' => 'Map a sysLocation value to another value.',
+        ],
+        'location_map_regex' => [
+            'description' => 'Specific Location Map using regex',
+            'help' => 'Map a sysLocation value to another value using regex.',
+        ],
+        'location_map_regex_sub' => [
+            'description' => 'Specific Location Map using regex substitution',
+            'help' => 'Substitute the sysLocation value using regex substitution.',
+        ],
         'login_message' => [
             'description' => 'Logon Message',
             'help' => 'Displayed on the login page',
@@ -1213,6 +1378,10 @@ return [
                 'help' => 'The port to use to connect to the OpenTSDB server',
             ],
         ],
+        'overview_show_sysDescr' => [
+            'description' => 'Show sysDescr on device overview',
+            'help' => 'Show the sysDescr on the device overview page',
+        ],
         'own_hostname' => [
             'description' => 'LibreNMS hostname',
             'help' => 'Should be set to the hostname/ip the librenms server is added as',
@@ -1257,6 +1426,10 @@ return [
                 'help' => 'Oxidized API url (For example: http://127.0.0.1:8888)',
             ],
         ],
+        'page_refresh' => [
+            'description' => 'Page Refresh',
+            'help' => 'How often to refresh the page in seconds. Set to 0 to disable.',
+        ],
         'password' => [
             'min_length' => [
                 'description' => 'Minimum password length',
@@ -1269,6 +1442,10 @@ return [
                 'help' => 'Enable PeeringDB lookup (data is downloaded with daily.sh)',
             ],
         ],
+        'percentile_value' => [
+            'description' => 'Percentile Value',
+            'help' => 'The percentile value to use for traffic graphs. 0 means disabled.',
+        ],
         'permission' => [
             'device_group' => [
                 'allow_dynamic' => [
@@ -1277,19 +1454,27 @@ return [
             ],
         ],
         'bad_if' => [
-            'description' => 'Bad Interface Names',
-            'help' => 'Network interface IF-MIB:!:ifName which should be ignored',
+            'description' => 'Bad Interface ifDescr',
+            'help' => 'Network interface IF-MIB:!:ifDescr which should be ignored',
         ],
         'bad_if_regexp' => [
-            'description' => 'Bad Interface Name Regex',
+            'description' => 'Bad Interface ifDescr Regex',
+            'help' => 'Network interface IF-MIB:!:ifDescr which should be ignored using regular expressions',
+        ],
+        'bad_ifalias_regexp' => [
+            'description' => 'Bad Interface ifAlias Regex',
+            'help' => 'Network interface IF-MIB:!:ifAlias which should be ignored using regular expressions',
+        ],
+        'bad_ifname_regexp' => [
+            'description' => 'Bad Interface ifName Regex',
             'help' => 'Network interface IF-MIB:!:ifName which should be ignored using regular expressions',
         ],
         'bad_ifoperstatus' => [
-            'description' => 'Bad Interface Operating Status',
+            'description' => 'Bad Interface ifOperStatus Status',
             'help' => 'Network interface IF-MIB:!:ifOperStatus which should be ignored',
         ],
         'bad_iftype' => [
-            'description' => 'Bad Interface Types',
+            'description' => 'Bad Interface ifType',
             'help' => 'Network interface IF-MIB:!:ifType which should be ignored',
         ],
         'ping' => [
@@ -1439,6 +1624,10 @@ return [
                 'description' => 'Printer Supplies',
             ],
         ],
+        'polling.selected_ports' => [
+            'description' => 'Selected Port Polling',
+            'help' => 'Enable selected port polling to only poll ports that are up and enabled',
+        ],
         'ports_fdb_purge' => [
             'description' => 'Port FDB entries older than',
             'help' => 'Cleanup done by daily.sh',
@@ -1490,10 +1679,42 @@ return [
             'help' => 'Networks from which devices will be discovered automatically.',
         ],
         'autodiscovery' => [
+            'bgp' => [
+                'description' => 'Enable BGP neighbor discovery',
+                'help' => 'Add links and neighbors based on BGP peers',
+            ],
+            'cdp_exclude' => [
+                'platform_regexp' => [
+                    'description' => 'CDP exclude platform regex',
+                    'help' => 'Prevent devices from being added by CDP if sysName matches regular expression',
+                ],
+            ],
             'nets-exclude' => [
                 'description' => 'Networks/IPs to be ignored',
                 'help' => 'Networks/IPs which will not be discovered automatically. Excludes also IPs from Autodiscovery Networks',
             ],
+            'ospf' => [
+                'description' => 'Enable OSPF neighbor discovery',
+                'help' => 'Add links and neighbors based on OSPF peers',
+            ],
+            'ospfv3' => [
+                'description' => 'Enable OSPFv3 neighbor discovery',
+                'help' => 'Add links and neighbors based on OSPFv3 peers',
+            ],
+            'xdp' => [
+                'description' => 'Enable xDP discovery protocols',
+                'help' => 'Use LLDP, CDP, etc protocols to discover network topology and neighbors and add them to LibreNMS',
+            ],
+            'xdp_exclude' => [
+                'sysname_regexp' => [
+                    'description' => 'xDP exclude sysName regex',
+                    'help' => 'Prevent devices from being added if sysName matches regular expression',
+                ],
+                'sysdesc_regexp' => [
+                    'description' => 'xDP exclude sysDescr regex',
+                    'help' => 'Prevent devices from being added if sysDescr matches regular expression',
+                ],
+            ],
         ],
         'radius' => [
             'default_roles' => [
@@ -1505,6 +1726,18 @@ return [
                 'help' => 'If enabled, roles will be set to the ones specified by the Filter-ID attribute or radius.default_roles at login.  Otherwise, they will be set when the user is created and never changed after that.',
             ],
         ],
+        'rancid_configs' => [
+            'description' => 'RANCID Configs',
+            'help' => 'RANCID configs directory, used to display config diffs on device pages',
+        ],
+        'rancid_repo_type' => [
+            'description' => 'RANCID Repository Type',
+            'help' => 'Type of repository used by RANCID, used to display config diffs on device pages',
+        ],
+        'rancid_ignorecomments' => [
+            'description' => 'RANCID Ignore Comments',
+            'help' => 'Ignore comments when comparing RANCID configs, used to display config diffs on device pages',
+        ],
         'reporting' => [
             'error' => [
                 'description' => 'Send Error Reports',
@@ -1523,6 +1756,10 @@ return [
                 'help' => 'Reports will only be sent every specified amount of seconds. Without this if you have an error in common code reporting can get out of hand. Set to 0 to disable throttling.',
             ],
         ],
+        'rewrite_if' => [
+            'description' => 'Rewrite ifDescr',
+            'help' => 'Rewrite ifDescr to remove the interface type and number, e.g. GigabitEthernet0/1 becomes GigabitEthernet',
+        ],
         'route_purge' => [
             'description' => 'Route entries older than',
             'help' => 'Cleanup done by daily.sh',
@@ -1619,6 +1856,12 @@ return [
                 ],
             ],
         ],
+        'sensors' => [
+            'guess_limits' => [
+                'description' => 'Guess sensor limits',
+                'help' => 'If enabled, LibreNMS will try to guess the sensor limits based on the sensor type and value. This is not always accurate and may lead to incorrect limits.',
+            ],
+        ],
         'service_master_timeout' => [
             'description' => 'Master Dispatcher Timeout',
             'help' => 'The amount of time before the master lock expires.  If master goes away, it will take this much time for another node to take over.  However if it takes longer than the timeout to dispatch the work, you will have multiple masters',
@@ -1694,6 +1937,18 @@ return [
             'description' => 'Shortened hostname maximum length',
             'help' => 'Shrinks hostname to maximum length, but always complete subdomain parts',
         ],
+        'show_locations' => [
+            'description' => 'Show locations in navigation',
+            'help' => 'Show the location in the navigation bar',
+        ],
+        'show_locations_dropdown' => [
+            'description' => 'Show locations in dropdown',
+            'help' => 'Show the location in the dropdown menu',
+        ],
+        'show_services' => [
+            'description' => 'Show services in navigation',
+            'help' => 'Show the services in the navigation bar',
+        ],
         'site_style' => [
             'description' => 'Default Theme',
             'options' => [
@@ -1791,6 +2046,10 @@ return [
         'snmpwalk' => [
             'description' => 'Path to snmpwalk',
         ],
+        'storage_perc_warn' => [
+            'description' => 'Storage Percentage Warning',
+            'help' => 'Percentage of storage used before a warning is raised. 0 disables warning.',
+        ],
         'syslog_filter' => [
             'description' => 'Filter syslog messages containing',
         ],
@@ -1842,6 +2101,10 @@ return [
         'virsh' => [
             'description' => 'Path to virsh',
         ],
+        'web_mouseover' => [
+            'description' => 'Enable mouseover',
+            'help' => 'Enables the mouseover graphs in the web interface',
+        ],
         'webui' => [
             'availability_map_box_size' => [
                 'description' => 'Availability box width',
@@ -1859,6 +2122,10 @@ return [
                 'description' => 'Use device groups filter',
                 'help' => 'Enable usage of device groups filter',
             ],
+            'custom_css' => [
+                'description' => 'Custom CSS',
+                'help' => 'Add custom CSS to the web interface',
+            ],
             'default_dashboard_id' => [
                 'description' => 'Default dashboard',
                 'help' => 'Global default dashboard_id for all users who do not have their own default set',
