@@ -5,7 +5,7 @@
 
     @foreach($data['stpInstances'] as $instance)
         <x-panel class="stp-panel">
-            <x-slot name="title"><span class="tw-font-bold">{{ trans('stp.stp_info') }}</span></x-slot>
+            <x-slot name="title"><span class="tw:font-bold">{{ trans('stp.stp_info') }}</span></x-slot>
             <table class="table table-condensed table-striped table-hover">
                 <tr>
                     <td>{{ trans('stp.root_bridge') }}</td>
@@ -42,7 +42,7 @@
                     <td>{{ trans('stp.designated_root') }}</td>
                     <td>
                         {{ \LibreNMS\Util\Mac::parse($instance['designatedRoot'])->readable() }}
-                        @if($url = \LibreNMS\Util\Url::deviceLink(\App\Facades\DeviceCache::get(\App\Models\Stp::where('bridgeAddress', $instance['designatedRoot'])->value('device_id'))))
+                        @if($url = \LibreNMS\Util\Url::deviceLink(\App\Facades\DeviceCache::get(\App\Models\Stp::where('bridgeAddress', $instance['designatedRoot'])->whereNot('bridgeAddress', '')->value('device_id'))))
                             ({!! $url !!})
                         @elseif($drVendor = \LibreNMS\Util\Mac::parse($instance['designatedRoot'])->vendor())
                             ({{ $drVendor }})
@@ -91,7 +91,7 @@
 
     @if($data['stpPorts'])
         <x-panel class="stp-panel">
-            <x-slot name="title"><span class="tw-font-bold">{{ trans('stp.stp_ports') }}</span></x-slot>
+            <x-slot name="title"><span class="tw:font-bold">{{ trans('stp.stp_ports') }}</span></x-slot>
             <div class="table-responsive">
                 <table id="stp-ports" class="table table-condensed table-hover">
                     <thead>
