@@ -34,6 +34,7 @@ use App\Http\Controllers\PortController;
 use App\Http\Controllers\PortGroupController;
 use App\Http\Controllers\PushNotificationController;
 use App\Http\Controllers\Select;
+use App\Http\Controllers\SensorController;
 use App\Http\Controllers\ServiceTemplateController;
 use App\Http\Controllers\SettingsController;
 use App\Http\Controllers\Table;
@@ -42,6 +43,7 @@ use App\Http\Controllers\UserPreferencesController;
 use App\Http\Controllers\ValidateController;
 use App\Http\Controllers\Widgets;
 use App\Http\Controllers\WidgetSettingsController;
+use App\Http\Controllers\WirelessSensorController;
 use App\Http\Middleware\AuthenticateGraph;
 use Illuminate\Support\Facades\Auth as AuthFacade;
 use Illuminate\Support\Facades\Route;
@@ -109,8 +111,8 @@ Route::middleware(['auth'])->group(function () {
     // Device Tabs
     Route::prefix('device/{device}')->name('device.')->group(function () {
         Route::put('notes', [Device\Tabs\NotesController::class, 'update'])->name('notes.update');
-        Route::put('module/{module}', [App\Http\Controllers\Device\Tabs\ModuleController::class, 'update'])->name('module.update');
-        Route::delete('module/{module}', [App\Http\Controllers\Device\Tabs\ModuleController::class, 'delete'])->name('module.delete');
+        Route::put('module/{module}', [Device\Tabs\ModuleController::class, 'update'])->name('module.update');
+        Route::delete('module/{module}', [Device\Tabs\ModuleController::class, 'delete'])->name('module.delete');
     });
 
     Route::match(['get', 'post'], 'device/{device}/{tab?}/{vars?}', [DeviceController::class, 'index'])
@@ -123,12 +125,12 @@ Route::middleware(['auth'])->group(function () {
     Route::prefix('maps')->group(function () {
         Route::resource('custom', CustomMapController::class, ['as' => 'maps'])
             ->parameters(['custom' => 'map'])->except('create');
-        Route::post('custom/{map}/clone', [Maps\CustomMapController::class, 'clone'])->name('maps.custom.clone');
+        Route::post('custom/{map}/clone', [CustomMapController::class, 'clone'])->name('maps.custom.clone');
         Route::get('custom/{map}/background', [CustomMapBackgroundController::class, 'get'])->name('maps.custom.background');
         Route::post('custom/{map}/background', [CustomMapBackgroundController::class, 'save'])->name('maps.custom.background.save');
         Route::get('custom/{map}/data', [CustomMapDataController::class, 'get'])->name('maps.custom.data');
         Route::post('custom/{map}/data', [CustomMapDataController::class, 'save'])->name('maps.custom.data.save');
-        Route::get('devicedependency', [Maps\DeviceDependencyController::class, 'dependencyMap']);
+        Route::get('devicedependency', [DeviceDependencyController::class, 'dependencyMap']);
         Route::post('getdevices', [Maps\MapDataController::class, 'getDevices'])->name('maps.getdevices');
         Route::post('getdevicelinks', [Maps\MapDataController::class, 'getDeviceLinks'])->name('maps.getdevicelinks');
         Route::post('getgeolinks', [Maps\MapDataController::class, 'getGeographicLinks'])->name('maps.getgeolinks');
@@ -168,7 +170,7 @@ Route::middleware(['auth'])->group(function () {
 
         Route::post('alert/transports/{transport}/test', [AlertTransportController::class, 'test'])->name('alert.transports.test');
 
-        Route::get('plugin/settings', \App\Http\Controllers\PluginAdminController::class)->name('plugin.admin');
+        Route::get('plugin/settings', App\Http\Controllers\PluginAdminController::class)->name('plugin.admin');
         Route::get('plugin/settings/{plugin:plugin_name}', PluginSettingsController::class)->name('plugin.settings');
         Route::post('plugin/settings/{plugin:plugin_name}', [PluginSettingsController::class, 'update'])->name('plugin.update');
 
@@ -184,6 +186,9 @@ Route::middleware(['auth'])->group(function () {
     Route::any('plugin/v1/{plugin:plugin_name}/{other?}', PluginLegacyController::class)->where('other', '(.*)')->name('plugin.legacy');
     Route::get('plugin/{plugin:plugin_name}', PluginPageController::class)->name('plugin.page');
 
+    Route::get('health/{metric?}/{legacyview?}', [SensorController::class, 'index'])->name('sensor.index');
+    Route::get('wireless/{metric}/{legacyview?}', [WirelessSensorController::class, 'index'])->name('wireless.index');
+
     // old route redirects
     Route::permanentRedirect('poll-log', 'poller/log');
 
@@ -210,7 +215,8 @@ Route::middleware(['auth'])->group(function () {
         Route::get('search/port', Ajax\PortSearchController::class);
         Route::post('set_map_group', [Ajax\AvailabilityMapController::class, 'setGroup']);
         Route::post('set_map_view', [Ajax\AvailabilityMapController::class, 'setView']);
-        Route::post('set_resolution', [Ajax\ResolutionController::class, 'set']);
+        Route::post('set_resolution', [Ajax\SessionController::class, 'resolution']);
+        Route::post('set_style', [Ajax\SessionController::class, 'style']);
         Route::get('netcmd', [Ajax\NetCommand::class, 'run']);
         Route::post('ripe/raw', [Ajax\RipeNccApiController::class, 'raw']);
         Route::get('snmp/capabilities', Ajax\SnmpCapabilities::class)->name('snmp.capabilities');
@@ -248,24 +254,35 @@ Route::middleware(['auth'])->group(function () {
         Route::prefix('table')->group(function () {
             Route::post('alert-schedule', Table\AlertScheduleController::class);
             Route::post('customers', Table\CustomersController::class);
-            Route::post('device', Table\DeviceController::class);
+            Route::post('diskio', Table\DiskioController::class)->name('table.diskio');
+            Route::post('device', Table\DeviceController::class)->name('table.device');
+            Route::get('device/export', [Table\DeviceController::class, 'export']);
             Route::post('edit-ports', Table\EditPortsController::class);
             Route::post('eventlog', Table\EventlogController::class);
             Route::post('fdb-tables', Table\FdbTablesController::class);
             Route::post('graylog', Table\GraylogController::class);
             Route::post('inventory', Table\InventoryController::class)->name('table.inventory');
+            Route::get('inventory/export', [Table\InventoryController::class, 'export']);
             Route::post('location', Table\LocationController::class);
-            Route::post('mempools', Table\MempoolsController::class);
-            Route::post('outages', Table\OutagesController::class);
+            Route::post('mempools', Table\MempoolsController::class)->name('table.mempools');
+            Route::get('mempools/export', [Table\MempoolsController::class, 'export']);
+            Route::post('outages', Table\OutagesController::class)->name('table.outages');
+            Route::get('outages/export', [Table\OutagesController::class, 'export']);
             Route::post('port-nac', Table\PortNacController::class)->name('table.port-nac');
             Route::post('port-stp', Table\PortStpController::class);
             Route::post('ports', Table\PortsController::class)->name('table.ports');
+            Route::get('ports/export', [Table\PortsController::class, 'export']);
             Route::post('processors', Table\ProcessorsController::class)->name('table.processors');
+            Route::get('processors/export', [Table\ProcessorsController::class, 'export']);
             Route::post('routes', Table\RoutesTablesController::class);
             Route::post('sensors', Table\SensorsController::class)->name('table.sensors');
+            Route::get('sensors/export', [Table\SensorsController::class, 'export']);
             Route::post('storages', Table\StoragesController::class)->name('table.storages');
+            Route::get('storages/export', [Table\StoragesController::class, 'export']);
             Route::post('syslog', Table\SyslogController::class);
+            Route::post('printer-supply', Table\PrinterSupplyController::class)->name('table.printer-supply');
             Route::post('tnmsne', Table\TnmsneController::class)->name('table.tnmsne');
+            Route::post('wireless', Table\WirelessSensorController::class)->name('table.wireless');
             Route::post('vlan-ports', Table\VlanPortsController::class)->name('table.vlan-ports');
             Route::post('vlan-devices', Table\VlanDevicesController::class)->name('table.vlan-devices');
             Route::post('vminfo', Table\VminfoController::class);
